#include <signal.h>
#include <stdio.h>
#include <unistd.h>

// This program illustrates how a process can protect itself against being
// killed by Ctrl-C (SIGINT, signal number 2) and the default termination
// signal sent by "kill" on the console (SIGTERM, number 15).

// However, SIGKILL (number 9) cannot be caught, the corresponding instruction
// in the code below will fail.

// In this variant, SIGINT is treated by an empty handler, which will interrupt
// the sleep() command.

void handler () {}

int main ()
{
	printf("my pid is %d\n",getpid());

	// INT = catch CTRL-C
	signal(SIGINT,handler);

	// TERM = catch "kill" from console
	signal(SIGTERM,SIG_IGN);

	// KILL: won't work
	signal(SIGKILL,SIG_IGN);

	while (1)
	{
		sleep(3);
		printf("I'm still alive...\n");
	}
}
