#include <signal.h>
#include <stdio.h>
#include <unistd.h>

// This program illustrates how a process can protect itself against being
// killed by Ctrl-C (SIGINT, signal number 2) and the default termination
// signal sent by "kill" on the console (SIGTERM, number 15).

// In this variant, the signal dispositions are changed using sigaction(),
// which is more portable than signal().

void handler (int nr, siginfo_t* siginfo, void* context)
{
	printf("signal %d sent from process %d\n",nr,siginfo->si_pid);
}

int main ()
{
	printf("my pid is %d\n",getpid());

        struct sigaction action1, action2;

	// catch SIGINT using handler
	action1.sa_flags = SA_RESTART;
        action1.sa_sigaction = handler;
        sigaction(SIGINT,&action1,NULL);

	// ignore SIGTERM
	action2.sa_handler = SIG_IGN;
        sigaction(SIGTERM,&action2,NULL);

	while (1)
	{
		sleep(3);
		printf("I'm still alive...\n");
	}
}
